| print.dm_filter | R Documentation |
prints a data frame version of selected info in a 'dm_filter' object or returns that data frame
## S3 method for class 'dm_filter'
print(x, ..., print = TRUE, seq = NULL, id = NULL, verbose = TRUE)
x |
a 'dm_filter' object |
... |
arguments passed to print.data.frame |
print |
if |
seq |
order in which to look at the filters |
id |
id-vector for units, necessarily in the same order as filter |
verbose |
logical, want funtion to provide messages? |
possibly a data frame
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.